
.. py:currentmodule:: pythreejs

ShapeGeometry
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: ShapeGeometry(shapes=[], )
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.BaseGeometry`.

    Three.js docs: https://threejs.org/docs/#api/geometries/ShapeGeometry


    .. py:attribute:: shapes

        .. sourcecode:: python

            Tuple().tag(sync=True, **widget_serialization)

    .. py:attribute:: curveSegments

        .. sourcecode:: python

            CInt(12, allow_none=False).tag(sync=True)

    .. py:attribute:: material

        .. sourcecode:: python

            CInt(0, allow_none=False).tag(sync=True)

